@@ -1,12 +1,12 @@
 import logging
-from typing import List, Union
+from typing import List, Optional, Union
 
 import aiohttp
 
 from .lock import DoorLock
-from .thermostat import Thermostat
-from .switch import BinarySwitch
 from .sensor import LeakSensor
+from .switch import BinarySwitch
+from .thermostat import Thermostat
 from .utils import Client
 
 _LOGGER = logging.getLogger(__name__)
@@ -26,7 +26,9 @@ class API:
     def __init__(
         self, email: str, password: str, aiohttp_session: aiohttp.ClientSession = None
     ):
-        self._device_list = []
+        self._device_list: List[
+            Union[DoorLock, Thermostat, BinarySwitch, LeakSensor]
+        ] = []
         self._email = email
         self._password = password
         self._session = aiohttp_session
@@ -65,7 +67,7 @@ class API:
 
             if device_object:
                 # pass in intial device config
-                device_object._fetch_state_helper(device)
+                await device_object._async_fetch_state()
 
                 # add device to device_list
                 self._device_list.append(device_object)
@@ -82,25 +84,33 @@ class API:
         """
         Gets list of DoorLocks
         """
-        return [x for x in self._device_list if isinstance(x, DoorLock)]
+        return self._list_maker(DoorLock)  # type: ignore
 
     def get_thermostats(self) -> List[Thermostat]:
         """
         Gets list of Thermostats
         """
-        return [x for x in self._device_list if isinstance(x, Thermostat)]
+        return self._list_maker(Thermostat)  # type: ignore
 
     def get_switches(self) -> List[BinarySwitch]:
         """
         Gets list of BinarySwitches
         """
-        return [x for x in self._device_list if isinstance(x, BinarySwitch)]
+        return self._list_maker(BinarySwitch)  # type: ignore
 
     def get_leak_sensors(self) -> List[LeakSensor]:
         """
         Gets list of LeakSensors
         """
-        return [x for x in self._device_list if isinstance(x, LeakSensor)]
+        return self._list_maker(LeakSensor)  # type: ignore
+
+    def _list_maker(
+        self, to_find: Union[LeakSensor, BinarySwitch, Thermostat, DoorLock]
+    ) -> List[Optional[Union[LeakSensor, BinarySwitch, Thermostat, DoorLock]]]:
+        """
+        Gets list of X type of item from ``device_list``
+        """
+        return [x for x in self._device_list if isinstance(x, to_find)]  # type: ignore
 
 
 async def async_login(
